@@ -1,6 +1,6 @@
 package DateTime::Infinite;
 BEGIN {
-  $DateTime::Infinite::VERSION = '0.65';
+  $DateTime::Infinite::VERSION = '0.66';
 }
 
 use strict;
@@ -28,11 +28,9 @@ sub _seconds_as_components {
 }
 
 sub _stringify {
-    (
-        $_[0]->{utc_rd_days} == DateTime::INFINITY
+    $_[0]->{utc_rd_days} == DateTime::INFINITY
         ? DateTime::INFINITY . ''
-        : DateTime::NEG_INFINITY . ''
-    );
+        : DateTime::NEG_INFINITY . '';
 }
 
 sub STORABLE_freeze {return}
@@ -40,7 +38,7 @@ sub STORABLE_thaw   {return}
 
 package DateTime::Infinite::Future;
 BEGIN {
-  $DateTime::Infinite::Future::VERSION = '0.65';
+  $DateTime::Infinite::Future::VERSION = '0.66';
 }
 
 use base qw(DateTime::Infinite);
@@ -64,7 +62,7 @@ use base qw(DateTime::Infinite);
 
 package DateTime::Infinite::Past;
 BEGIN {
-  $DateTime::Infinite::Past::VERSION = '0.65';
+  $DateTime::Infinite::Past::VERSION = '0.66';
 }
 
 use base qw(DateTime::Infinite);
@@ -100,12 +98,12 @@ DateTime::Infinite - Infinite past and future DateTime objects
 
 =head1 VERSION
 
-version 0.65
+version 0.66
 
 =head1 SYNOPSIS
 
-  my $future = DateTime::Infinite::Future->new;
-  my $past   = DateTime::Infinite::Past->new;
+  my $future = DateTime::Infinite::Future->new();
+  my $past   = DateTime::Infinite::Past->new();
 
 =head1 DESCRIPTION
 
@@ -118,19 +116,19 @@ changed.
 =head1 BUGS
 
 There seem to be lots of problems when dealing with infinite numbers
-on Win32.  This may be a problem with this code, Perl, or Win32's IEEE
-math implementation.  Either way, the module may not be well-behaved
+on Win32. This may be a problem with this code, Perl, or Win32's IEEE
+math implementation. Either way, the module may not be well-behaved
 on Win32 operating systems.
 
 =head1 METHODS
 
 The only constructor for these two classes is the C<new()> method, as
-shown in the L<SYNOPSIS|/SYNOPSIS>.  This method takes no parameters.
+shown in the L<SYNOPSIS|/SYNOPSIS>. This method takes no parameters.
 
 All "get" methods in this module simply return infinity, positive or
-negative.  If the method is expected to return a string, it return the
+negative. If the method is expected to return a string, it return the
 string representation of positive or negative infinity used by your
-system.  For example, on my system calling C<year()> returns a number
+system. For example, on my system calling C<year()> returns a number
 which when printed appears either "inf" or "-inf".
 
 The object is not mutable, so the C<set()>, C<set_time_zone()>, and
